Error

Enum Error 

pub enum Error {
    ProofCat(Error),
    Plonkish(Error),
    ColumnOutOfBounds {
        index: usize,
        column_count: usize,
    },
    EmptyTrace,
    ColumnCountMismatch {
        expected: usize,
        actual: usize,
    },
    TraceNotPowerOfTwo {
        row_count: usize,
    },
    UnsatisfiedAirConstraint {
        row: usize,
    },
    NoConstraints,
    InsufficientRows {
        row_count: usize,
    },
    RowLengthMismatch {
        row: usize,
        expected: usize,
        actual: usize,
    },
}
All errors that can arise in machine-cat.

Variants



ProofCat(Error)

An error propagated from proof-cat.



Plonkish(Error)

An error propagated from plonkish-cat.



ColumnOutOfBounds

Column index out of bounds.

Fields

index: usize

The column index that was accessed.

column_count: usize

The total number of columns.



EmptyTrace

Trace has zero rows.



ColumnCountMismatch

Trace column count does not match the AIR’s column count.

Fields

expected: usize

The expected column count (from the AIR).

actual: usize

The actual column count (from the trace).



TraceNotPowerOfTwo

Trace row count is not a power of two.

Fields

row_count: usize

The row count.



UnsatisfiedAirConstraint

An AIR constraint was not satisfied at a row pair.

Fields

row: usize

The row index of the failing pair.



NoConstraints

AIR has no constraints.



InsufficientRows

Trace has fewer than 2 rows.

Fields

row_count: usize

The row count.



RowLengthMismatch

Row length does not match column count.

Fields

row: usize

The row index.

expected: usize

The expected length.

actual: usize

The actual length.